==> google-cloud-pubsublite-0.5.0-sources.jar: com/google/cloud/pubsublite/internal/wire/SinglePartitionPublisherBuilder.java <==
/*
 * Copyright 2020 Google LLC
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.google.cloud.pubsublite.internal.wire;

import com.google.api.gax.batching.BatchingSettings;
import com.google.auto.value.AutoValue;
import com.google.cloud.pubsublite.Partition;
import com.google.cloud.pubsublite.PublishMetadata;
import com.google.cloud.pubsublite.TopicPath;
import com.google.cloud.pubsublite.internal.Publisher;
import com.google.cloud.pubsublite.proto.PublisherServiceGrpc;
import io.grpc.StatusException;
import java.util.Optional;

@AutoValue
public abstract class SinglePartitionPublisherBuilder {
  // Required parameters.
  abstract TopicPath topic();

  abstract Partition partition();

  // Optional parameters.
  abstract Optional<PublisherServiceGrpc.PublisherServiceStub> stub();

  abstract Optional<BatchingSettings> batchingSettings();

  // Rarely set parameters.
  abstract PubsubContext context();

  // For testing.
  abstract PublisherBuilder.Builder underlyingBuilder();

  public static Builder newBuilder() {
    return new AutoValue_SinglePartitionPublisherBuilder.Builder()
        .setContext(PubsubContext.of())
        .setUnderlyingBuilder(PublisherBuilder.builder());
  }

  @AutoValue.Builder
  @SuppressWarnings("CheckReturnValue")
  public abstract static class Builder {
    // Required parameters.
    public abstract Builder setTopic(TopicPath topic);

    public abstract Builder setPartition(Partition partition);

    // Optional parameters.
    public abstract Builder setStub(Optional<PublisherServiceGrpc.PublisherServiceStub> stub);

    public abstract Builder setBatchingSettings(Optional<BatchingSettings> batchingSettings);

    // Rarely set parameters.
    public abstract Builder setContext(PubsubContext context);

    // For testing.
    abstract Builder setUnderlyingBuilder(PublisherBuilder.Builder underlyingBuilder);

    abstract SinglePartitionPublisherBuilder autoBuild();

    public Publisher<PublishMetadata> build() throws StatusException {
      SinglePartitionPublisherBuilder builder = autoBuild();
      PublisherBuilder.Builder publisherBuilder =
          builder
              .underlyingBuilder()
              .setTopic(builder.topic())
              .setPartition(builder.partition())
              .setContext(builder.context());
      builder.stub().ifPresent(publisherBuilder::setStub);
      builder.batchingSettings().ifPresent(publisherBuilder::setBatching);
      return new SinglePartitionPublisher(publisherBuilder.build(), builder.partition());
    }
  }
}

==> google-cloud-pubsublite-0.7.0-sources.jar: com/google/cloud/pubsublite/internal/wire/SinglePartitionPublisherBuilder.java <==
/*
 * Copyright 2020 Google LLC
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.google.cloud.pubsublite.internal.wire;

import com.google.api.gax.batching.BatchingSettings;
import com.google.api.gax.rpc.ApiException;
import com.google.auto.value.AutoValue;
import com.google.cloud.pubsublite.Partition;
import com.google.cloud.pubsublite.PublishMetadata;
import com.google.cloud.pubsublite.TopicPath;
import com.google.cloud.pubsublite.internal.Publisher;
import com.google.cloud.pubsublite.v1.PublisherServiceClient;
import java.util.Optional;

@AutoValue
public abstract class SinglePartitionPublisherBuilder {
  // Required parameters.
  abstract TopicPath topic();

  abstract Partition partition();

  // Optional parameters.
  abstract Optional<PublisherServiceClient> serviceClient();

  abstract Optional<BatchingSettings> batchingSettings();

  // Rarely set parameters.
  abstract PubsubContext context();

  // For testing.
  abstract PublisherBuilder.Builder underlyingBuilder();

  public static Builder newBuilder() {
    return new AutoValue_SinglePartitionPublisherBuilder.Builder()
        .setContext(PubsubContext.of())
        .setUnderlyingBuilder(PublisherBuilder.builder());
  }

  @AutoValue.Builder
  @SuppressWarnings("CheckReturnValue")
  public abstract static class Builder {
    // Required parameters.
    public abstract Builder setTopic(TopicPath topic);

    public abstract Builder setPartition(Partition partition);

    // Optional parameters.
    public abstract Builder setServiceClient(PublisherServiceClient serviceClient);

    public abstract Builder setBatchingSettings(BatchingSettings batchingSettings);

    // Rarely set parameters.
    public abstract Builder setContext(PubsubContext context);

    // For testing.
    abstract Builder setUnderlyingBuilder(PublisherBuilder.Builder underlyingBuilder);

    abstract SinglePartitionPublisherBuilder autoBuild();

    public Publisher<PublishMetadata> build() throws ApiException {
      SinglePartitionPublisherBuilder builder = autoBuild();
      PublisherBuilder.Builder publisherBuilder =
          builder
              .underlyingBuilder()
              .setTopic(builder.topic())
              .setPartition(builder.partition())
              .setContext(builder.context());
      builder.serviceClient().ifPresent(publisherBuilder::setServiceClient);
      builder.batchingSettings().ifPresent(publisherBuilder::setBatching);
      return new SinglePartitionPublisher(publisherBuilder.build(), builder.partition());
    }
  }
}
